'''/*---------------------------------------------------------------------------------------------
 *  Copyright (c) VituTech. All rights reserved.
 *  Licensed under the Apache License 2.0. See License.txt in the project root for license information.
 *--------------------------------------------------------------------------------------------*/
'''
# import pandas as pd
# import numpy as np
#
# pd.set_option('display.max_rows', None)  # 让行显示完
# pd.set_option('display.max_columns', None)  # 让列显示完
# # pd.set_option('display.height',1000)               # 高度最大显示1000行
# pd.set_option('display.width', 1000)  # 宽度最大显示1000列
# exchange = 'binance'
# df_data = pd.read_csv('./{}_min_order.csv'.format(exchange))
# print(df_data)
# a = df_data[['baseAsset', 'quoteAsset', 'minTradeAmount', 'minOrderValue']]
# b = np.array(a)
# print(b)
# for i in b:
#     min_order['binance'][i[0] + '/' + i[1]] = {'min_order_qty': i[2],
#                                                'min_order_amount': i[3]}
# print(min_order)

min_order = {'binance': {'ETH/BTC': {'min_order_qty': 0.001, 'min_order_amount': 0.0001},
                         'LTC/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'BNB/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'NEO/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'QTUM/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'EOS/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'SNT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'BNT/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'GAS/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'BNB/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'BTC/USDT': {'min_order_qty': 1e-06, 'min_order_amount': 10.0},
                         'ETH/USDT': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'OAX/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'DNT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'MCO/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'MCO/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'WTC/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'WTC/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'LRC/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'LRC/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'QTUM/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'YOYO/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'OMG/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'OMG/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'ZRX/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ZRX/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'STRAT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'STRAT/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'SNGLS/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'SNGLS/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'BQX/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'BQX/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'KNC/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'KNC/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'FUN/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'FUN/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'SNM/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'SNM/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'NEO/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'IOTA/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'IOTA/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'LINK/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'LINK/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'XVG/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'XVG/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'MDA/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'MDA/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'MTL/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'MTL/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'EOS/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'SNT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ETC/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'ETC/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'MTH/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'MTH/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'ENG/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ENG/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'DNT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ZEC/BTC': {'min_order_qty': 0.001, 'min_order_amount': 0.0001},
                         'ZEC/ETH': {'min_order_qty': 0.001, 'min_order_amount': 0.01},
                         'BNT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'AST/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'AST/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'DASH/BTC': {'min_order_qty': 0.001, 'min_order_amount': 0.0001},
                         'DASH/ETH': {'min_order_qty': 0.001, 'min_order_amount': 0.01},
                         'OAX/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'BTG/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'BTG/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'EVX/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'EVX/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'REQ/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'REQ/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'VIB/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'VIB/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'TRX/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'TRX/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'POWR/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'POWR/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'ARK/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ARK/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'YOYO/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'XRP/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'XRP/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'ENJ/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ENJ/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'STORJ/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'STORJ/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'BNB/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'YOYO/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'POWR/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'KMD/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'KMD/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'NULS/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'RCN/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'RCN/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'RCN/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'NULS/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'NULS/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'RDN/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'RDN/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'RDN/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'XMR/BTC': {'min_order_qty': 0.001, 'min_order_amount': 0.0001},
                         'XMR/ETH': {'min_order_qty': 0.001, 'min_order_amount': 0.01},
                         'DLT/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'WTC/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'DLT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'DLT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'AMB/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'AMB/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'AMB/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'BAT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'BAT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'BAT/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'BCPT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'BCPT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'BCPT/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'ARN/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ARN/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'GVT/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'GVT/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'CDT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'CDT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'GXS/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'GXS/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'NEO/USDT': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'NEO/BNB': {'min_order_qty': 0.01, 'min_order_amount': 0.1},
                         'POE/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'POE/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'QSP/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'QSP/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'QSP/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'BTS/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'BTS/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'BTS/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'XZC/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'XZC/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'XZC/BNB': {'min_order_qty': 0.01, 'min_order_amount': 0.1},
                         'LSK/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'LSK/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'LSK/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'TNT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'TNT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'FUEL/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'MANA/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'MANA/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'BCD/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'BCD/ETH': {'min_order_qty': 0.001, 'min_order_amount': 0.01},
                         'DGD/BTC': {'min_order_qty': 0.001, 'min_order_amount': 0.0001},
                         'DGD/ETH': {'min_order_qty': 0.001, 'min_order_amount': 0.01},
                         'IOTA/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'ADX/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ADX/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'ADX/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'ADA/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ADA/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'PPT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'PPT/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'CMT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'CMT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'CMT/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'XLM/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'XLM/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'XLM/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'CND/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'CND/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'CND/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'LEND/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'LEND/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'WABI/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'WABI/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'WABI/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'LTC/ETH': {'min_order_qty': 0.001, 'min_order_amount': 0.01},
                         'LTC/USDT': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'LTC/BNB': {'min_order_qty': 0.001, 'min_order_amount': 0.1},
                         'TNB/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'TNB/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'WAVES/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'WAVES/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'WAVES/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'GTO/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'GTO/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'GTO/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'ICX/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ICX/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'ICX/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'OST/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'OST/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'OST/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'ELF/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ELF/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'AION/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'AION/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'AION/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'NEBL/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'NEBL/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'NEBL/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'BRD/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'BRD/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'BRD/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'MCO/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'EDO/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'EDO/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'NAV/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'NAV/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'NAV/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'LUN/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'APPC/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'APPC/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'APPC/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'VIBE/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'VIBE/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'RLC/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'RLC/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'RLC/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'INS/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'INS/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'PIVX/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'PIVX/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'PIVX/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'IOST/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'IOST/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'STEEM/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'STEEM/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'STEEM/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'NANO/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'NANO/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'NANO/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'VIA/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'VIA/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'VIA/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'BLZ/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'BLZ/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'BLZ/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'AE/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'AE/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'AE/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'NCASH/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'NCASH/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'POA/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'POA/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'POA/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'ZIL/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ZIL/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'ZIL/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'ONT/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'ONT/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'ONT/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'STORM/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'STORM/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'STORM/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'QTUM/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'QTUM/USDT': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'XEM/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'XEM/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'XEM/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'WAN/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'WAN/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'WAN/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'WPR/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'WPR/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'QLC/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'QLC/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'SYS/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'SYS/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'SYS/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'QLC/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'GRS/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'GRS/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'ADA/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'ADA/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'GNT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'GNT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'GNT/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'LOOM/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'LOOM/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'LOOM/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'XRP/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'REP/BTC': {'min_order_qty': 0.001, 'min_order_amount': 0.0001},
                         'REP/ETH': {'min_order_qty': 0.001, 'min_order_amount': 0.01},
                         'REP/BNB': {'min_order_qty': 0.01, 'min_order_amount': 0.1},
                         'BTC/TUSD': {'min_order_qty': 1e-06, 'min_order_amount': 10.0},
                         'ETH/TUSD': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'ZEN/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'ZEN/ETH': {'min_order_qty': 0.001, 'min_order_amount': 0.01},
                         'ZEN/BNB': {'min_order_qty': 0.01, 'min_order_amount': 0.1},
                         'SKY/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'SKY/ETH': {'min_order_qty': 0.001, 'min_order_amount': 0.01},
                         'SKY/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'EOS/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'EOS/BNB': {'min_order_qty': 0.01, 'min_order_amount': 0.1},
                         'CVC/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'CVC/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'CVC/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'THETA/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'THETA/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'THETA/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'XRP/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'TUSD/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'IOTA/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'XLM/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'IOTX/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'IOTX/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'QKC/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'QKC/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'AGI/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'AGI/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'AGI/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'NXS/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'NXS/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'NXS/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'ENJ/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'DATA/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'DATA/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'ONT/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'TRX/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'TRX/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'ETC/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'ETC/BNB': {'min_order_qty': 0.01, 'min_order_amount': 0.1},
                         'ICX/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'SC/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'SC/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'SC/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'NPXS/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'KEY/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'KEY/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'NAS/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'NAS/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'NAS/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'MFT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'MFT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'MFT/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'DENT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'ARDR/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ARDR/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'ARDR/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'NULS/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'HOT/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'HOT/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'VET/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'VET/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'VET/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'VET/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'DOCK/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'DOCK/ETH': {'min_order_qty': 1.0, 'min_order_amount': 0.01},
                         'POLY/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'POLY/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'HC/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'HC/ETH': {'min_order_qty': 0.01, 'min_order_amount': 0.01},
                         'GO/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'GO/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'PAX/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'RVN/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'RVN/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'DCR/BTC': {'min_order_qty': 0.001, 'min_order_amount': 0.0001},
                         'DCR/BNB': {'min_order_qty': 0.001, 'min_order_amount': 0.1},
                         'MITH/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'MITH/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'BCH/BTC': {'min_order_qty': 0.001, 'min_order_amount': 0.0001},
                         'BCH/USDT': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'BNB/PAX': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BTC/PAX': {'min_order_qty': 1e-06, 'min_order_amount': 10.0},
                         'ETH/PAX': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'XRP/PAX': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'EOS/PAX': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'XLM/PAX': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'REN/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'REN/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'BNB/TUSD': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'XRP/TUSD': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'EOS/TUSD': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'XLM/TUSD': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'BNB/USDC': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BTC/USDC': {'min_order_qty': 1e-06, 'min_order_amount': 10.0},
                         'ETH/USDC': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'XRP/USDC': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'EOS/USDC': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'XLM/USDC': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'USDC/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'ADA/TUSD': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'TRX/TUSD': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'NEO/TUSD': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'TRX/XRP': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'XZC/XRP': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'PAX/TUSD': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'USDC/TUSD': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'USDC/PAX': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'LINK/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'LINK/TUSD': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'LINK/PAX': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'LINK/USDC': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'WAVES/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'WAVES/TUSD': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'WAVES/USDC': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BCH/TUSD': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'BCH/PAX': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'BCH/USDC': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'LTC/TUSD': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'LTC/PAX': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'LTC/USDC': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'TRX/PAX': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'TRX/USDC': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'BTT/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'BTT/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'BNB/USDS': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BTC/USDS': {'min_order_qty': 1e-06, 'min_order_amount': 10.0},
                         'USDS/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'USDS/PAX': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'USDS/TUSD': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'USDS/USDC': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BTT/PAX': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'BTT/TUSD': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'BTT/USDC': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'ONG/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'ONG/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ONG/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'HOT/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'HOT/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'ZIL/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'ZRX/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'ZRX/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'FET/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'FET/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'FET/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BAT/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'XMR/BNB': {'min_order_qty': 0.001, 'min_order_amount': 0.1},
                         'XMR/USDT': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'ZEC/BNB': {'min_order_qty': 0.001, 'min_order_amount': 0.1},
                         'ZEC/USDT': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'ZEC/PAX': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'ZEC/TUSD': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'ZEC/USDC': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'IOST/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'IOST/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'CELR/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'CELR/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'CELR/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'ADA/PAX': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'ADA/USDC': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'NEO/PAX': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'NEO/USDC': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'DASH/BNB': {'min_order_qty': 0.001, 'min_order_amount': 0.1},
                         'DASH/USDT': {'min_order_qty': 1e-05, 'min_order_amount': 10.0},
                         'NANO/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'OMG/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'OMG/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'THETA/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'ENJ/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'MITH/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'MATIC/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'MATIC/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'MATIC/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'ATOM/BNB': {'min_order_qty': 0.01, 'min_order_amount': 0.1},
                         'ATOM/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'ATOM/USDT': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'ATOM/USDC': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'ATOM/PAX': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'ATOM/TUSD': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'ETC/USDC': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'ETC/PAX': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'ETC/TUSD': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'BAT/USDC': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BAT/PAX': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BAT/TUSD': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'PHB/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'PHB/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'PHB/TUSD': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'TFUEL/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'TFUEL/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'TFUEL/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'ONE/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'ONE/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ONE/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'ONE/USDC': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'FTM/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'FTM/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'FTM/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'FTM/USDC': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'ALGO/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'ALGO/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ALGO/USDT': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'ALGO/TUSD': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'ALGO/PAX': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'ALGO/USDC': {'min_order_qty': 0.001, 'min_order_amount': 10.0},
                         'GTO/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'ERD/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'ERD/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ERD/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'DOGE/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'DOGE/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'DOGE/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'DUSK/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'DUSK/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'DUSK/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'DUSK/USDC': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'DUSK/PAX': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BGBP/USDC': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'ANKR/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'ANKR/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'ANKR/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'ONT/PAX': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'ONT/USDC': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'WIN/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'WIN/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'WIN/USDC': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'COS/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'COS/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'COS/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'NPXS/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'NPXS/USDC': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'COCOS/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'COCOS/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'COCOS/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'MTL/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'TOMO/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'TOMO/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'TOMO/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'TOMO/USDC': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'PERL/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'PERL/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'PERL/USDC': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'PERL/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'DENT/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'MFT/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'KEY/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'STORM/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'DOCK/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'WAN/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'FUN/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'CVC/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'BTT/TRX': {'min_order_qty': 0.1, 'min_order_amount': 0.001},
                         'WIN/TRX': {'min_order_qty': 0.1, 'min_order_amount': 0.001},
                         'CHZ/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'CHZ/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'CHZ/USDT': {'min_order_qty': 1.0, 'min_order_amount': 10.0},
                         'BAND/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'BAND/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'BAND/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BNB/BUSD': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BTC/BUSD': {'min_order_qty': 1e-06, 'min_order_amount': 10.0},
                         'BUSD/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'BEAM/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'BEAM/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'BEAM/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'XTZ/BNB': {'min_order_qty': 0.1, 'min_order_amount': 0.1},
                         'XTZ/BTC': {'min_order_qty': 0.01, 'min_order_amount': 0.0001},
                         'XTZ/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'REN/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'RVN/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'HC/USDT': {'min_order_qty': 0.01, 'min_order_amount': 10.0},
                         'HBAR/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'HBAR/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'HBAR/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0},
                         'NKN/BNB': {'min_order_qty': 1.0, 'min_order_amount': 0.1},
                         'NKN/BTC': {'min_order_qty': 1.0, 'min_order_amount': 0.0001},
                         'NKN/USDT': {'min_order_qty': 0.1, 'min_order_amount': 10.0}}}

